__title__ = "dxh"
__version__ = "0.1.3"
__description__ = "dxh is Convert python objects to camel case and snake case keys using this library."
__author__ = "Mohammad Foysal"
__url__ = "https://github.com/iamfoysal/dxh"
__license__ = "MIT"
__keywords__ = [
    "python", "object", "convert", "camel", "snake", "case", "keys", "to", "camel", "case",
]
